#  ~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~
#  MIT License
#
#  Copyright (c) 2021 Nathan Juraj Michlo
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in
#  all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
#  ~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~

# supervised frameworks
from disent.frameworks.vae._supervised__tvae import TripletVae
from disent.frameworks.vae._supervised__adaneg_tvae import AdaNegTripletVae

# unsupervised frameworks
from disent.frameworks.vae._unsupervised__betatcvae import BetaTcVae
from disent.frameworks.vae._unsupervised__betavae import BetaVae
from disent.frameworks.vae._unsupervised__dfcvae import DfcVae
from disent.frameworks.vae._unsupervised__dipvae import DipVae
from disent.frameworks.vae._unsupervised__infovae import InfoVae
from disent.frameworks.vae._unsupervised__vae import Vae
from disent.frameworks.vae._unsupervised__dotvae import DataOverlapTripletVae

# weakly supervised frameworks
from disent.frameworks.vae._weaklysupervised__adavae import AdaVae
from disent.frameworks.vae._weaklysupervised__adavae import AdaGVaeMinimal
